@@ -8,19 +8,23 @@
  */
 use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
-use pyo3::types::{PyBytes, PyDict, PyString};
+use pyo3::types::{PyBytes, PyDict, PyList, PyString};
 use std::collections::HashMap;
 use tokio::runtime::Runtime;
-use vegafusion_core::error::ToExternalError;
-use vegafusion_core::proto::gen::pretransform::pre_transform_warning::WarningType;
-use vegafusion_core::proto::gen::services::pre_transform_result;
+use vegafusion_core::error::{ToExternalError, VegaFusionError};
+use vegafusion_core::proto::gen::pretransform::pre_transform_spec_warning::WarningType;
+use vegafusion_core::proto::gen::pretransform::pre_transform_values_warning::WarningType as ValueWarningType;
+use vegafusion_core::proto::gen::services::pre_transform_spec_result;
 use vegafusion_rt_datafusion::task_graph::runtime::TaskGraphRuntime;
 
 use serde::{Deserialize, Serialize};
 use vegafusion_core::data::dataset::VegaFusionDataset;
+use vegafusion_core::proto::gen::tasks::Variable;
+use vegafusion_core::task_graph::graph::ScopedVariable;
+use vegafusion_core::task_graph::task_value::TaskValue;
 
 #[derive(Clone, Serialize, Deserialize)]
-struct PreTransformWarning {
+struct PreTransformSpecWarning {
     #[serde(rename = "type")]
     pub typ: String,
     pub message: String,
@@ -32,6 +36,21 @@ struct PyTaskGraphRuntime {
     tokio_runtime: Runtime,
 }
 
+fn deserialize_inline_datasets(
+    inline_datasets: &PyDict,
+) -> PyResult<HashMap<String, VegaFusionDataset>> {
+    inline_datasets
+        .iter()
+        .map(|(name, table_bytes)| {
+            let name = name.cast_as::<PyString>()?;
+            let ipc_bytes = table_bytes.cast_as::<PyBytes>()?;
+            let ipc_bytes = ipc_bytes.as_bytes();
+            let dataset = VegaFusionDataset::from_table_ipc_bytes(ipc_bytes)?;
+            Ok((name.to_string(), dataset))
+        })
+        .collect::<PyResult<HashMap<_, _>>>()
+}
+
 #[pymethods]
 impl PyTaskGraphRuntime {
     #[new]
@@ -73,16 +92,7 @@ impl PyTaskGraphRuntime {
         row_limit: Option<u32>,
         inline_datasets: &PyDict,
     ) -> PyResult<(String, String)> {
-        let inline_datasets: HashMap<_, _> = inline_datasets
-            .iter()
-            .map(|(name, table_bytes)| {
-                let name = name.cast_as::<PyString>()?;
-                let ipc_bytes = table_bytes.cast_as::<PyBytes>()?;
-                let ipc_bytes = ipc_bytes.as_bytes();
-                let dataset = VegaFusionDataset::from_table_ipc_bytes(ipc_bytes)?;
-                Ok((name.to_string(), dataset))
-            })
-            .collect::<PyResult<HashMap<_, _>>>()?;
+        let inline_datasets = deserialize_inline_datasets(inline_datasets)?;
 
         let response = self
             .tokio_runtime
@@ -95,32 +105,32 @@ impl PyTaskGraphRuntime {
             ))?;
 
         match response.result.unwrap() {
-            pre_transform_result::Result::Error(err) => {
+            pre_transform_spec_result::Result::Error(err) => {
                 Err(PyValueError::new_err(format!("{:?}", err)))
             }
-            pre_transform_result::Result::Response(response) => {
+            pre_transform_spec_result::Result::Response(response) => {
                 let warnings: Vec<_> = response.warnings.iter().map(|warning| {
                     match warning.warning_type.as_ref().unwrap() {
                         WarningType::RowLimit(_) => {
-                            PreTransformWarning {
+                            PreTransformSpecWarning {
                                 typ: "RowLimitExceeded".to_string(),
                                 message: "Some datasets in resulting Vega specification have been truncated to the provided row limit".to_string()
                             }
                         }
                         WarningType::BrokenInteractivity(_) => {
-                            PreTransformWarning {
+                            PreTransformSpecWarning {
                                 typ: "BrokenInteractivity".to_string(),
                                 message: "Some interactive features may have been broken in the resulting Vega specification".to_string()
                             }
                         }
                         WarningType::Unsupported(_) => {
-                            PreTransformWarning {
+                            PreTransformSpecWarning {
                                 typ: "Unsupported".to_string(),
                                 message: "Unable to pre-transform any datasets in the Vega specification".to_string()
                             }
                         }
                         WarningType::Planner(warning) => {
-                            PreTransformWarning {
+                            PreTransformSpecWarning {
                                 typ: "Planner".to_string(),
                                 message: warning.message.clone()
                             }
@@ -133,6 +143,64 @@ impl PyTaskGraphRuntime {
         }
     }
 
+    pub fn pre_transform_datasets(
+        &self,
+        spec: String,
+        variables: Vec<(String, Vec<u32>)>,
+        local_tz: String,
+        default_input_tz: Option<String>,
+        inline_datasets: &PyDict,
+    ) -> PyResult<(PyObject, String)> {
+        let inline_datasets = deserialize_inline_datasets(inline_datasets)?;
+
+        // Build variables
+        let variables: Vec<ScopedVariable> = variables
+            .iter()
+            .map(|input_var| {
+                let var = Variable::new_data(&input_var.0);
+                let scope = input_var.1.clone();
+                (var, scope)
+            })
+            .collect();
+
+        let (values, warnings) = self
+            .tokio_runtime
+            .block_on(self.runtime.pre_transform_values(
+                &spec,
+                &variables,
+                &local_tz,
+                &default_input_tz,
+                inline_datasets,
+            ))?;
+
+        let warnings: Vec<_> = warnings
+            .iter()
+            .map(|warning| match warning.warning_type.as_ref().unwrap() {
+                ValueWarningType::Planner(planner_warning) => PreTransformSpecWarning {
+                    typ: "Planner".to_string(),
+                    message: planner_warning.message.clone(),
+                },
+            })
+            .collect();
+
+        let response_list: PyObject = Python::with_gil(|py| -> PyResult<PyObject> {
+            let response_list = PyList::empty(py);
+            for value in values {
+                let bytes: PyObject = if let TaskValue::Table(table) = value {
+                    PyBytes::new(py, table.to_ipc_bytes()?.as_slice()).into()
+                } else {
+                    return Err(PyErr::from(VegaFusionError::internal(
+                        "Unexpected value type",
+                    )));
+                };
+                response_list.append(bytes)?;
+            }
+            Ok(response_list.into())
+        })?;
+
+        Ok((response_list, serde_json::to_string(&warnings).unwrap()))
+    }
+
     pub fn clear_cache(&self) {
         self.tokio_runtime.block_on(self.runtime.clear_cache());
     }
